from setuptools import setup

setup(name='mh_universal_functions',
      version='2020.6.27.1',
      description='General functions',
      url='',
      author='MH',
      author_email='mh@example.com',
      license='MIT',
      packages=['mh_universal_functions'],
      zip_safe=False)
